OSSP CVS Repository

ossp - Difference in ossp-pkg/rc/rc.h versions 1.48 and 1.49
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/rc/rc.h 1.48 -> 1.49

--- rc.h 2003/06/13 18:33:07     1.48
+++ rc.h 2003/06/18 14:35:29     1.49
@@ -98,11 +98,10 @@
 rc_return_t clioptSetrcfile(const char *);
 rc_return_t clioptSetsecs(const char **);
 
-/* Analyser function prototypes */
-rc_anal_t *analNew(void);
-rc_return_t analDelete(rc_anal_t *);
-rc_return_t analRcs(rc_anal_t *, const char *);
-rc_return_t analGloblocs(rc_anal_t *);
+/* List function prototypes */
+rc_list_t *listNew(void);
+rc_return_t listDelete(rc_list_t *);
+rc_return_t listPopulate(rc_list_t *, const char *);
 
 /* Script function prototypes */
 rc_script_t *scriptNew(void);
@@ -114,12 +113,13 @@
 const char *scriptTostring(rc_script_t *);
 rc_return_t scriptDelete(rc_script_t *);
 
-/* Label function prototypes */
-rc_label_t *labelNew(const char *);
-rc_return_t labelAppendsec(rc_label_t *, rc_section_t *);
-rc_return_t labelDelete(rc_label_t *);
-const char *labelGetname(rc_label_t *);
-rc_return_t labelSetname(rc_label_t *, const char *);
+/* Rcfile function prototypes */
+rc_file_t  *rcfileNew(const char *);
+rc_return_t rcfileAppendsec(rc_file_t *, rc_section_t *);
+const char *rcfileGetname(rc_file_t *);
+rc_return_t rcfileSetname(rc_file_t *, const char *);
+short rcfileExists(rc_file_t *);
+rc_return_t rcfileDelete(rc_file_t *);
 
 /* Section function prototypes */
 rc_section_t *sectionNew(const char *);

CVSTrac 2.0.1